%global version 1.4.1
%global rpmrelease 4
%global debianpatchrelease 1.4.1-3

# systemd options
%global _has_systemd %(eval rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  %global _servicefile_postfix %{_has_systemd}.service
  %global _pidbasedir /run
%else
  %global _servicefile_postfix init
  %global _pidbasedir %{_var}/run
%endif

%global _user dkim

Summary: SMTP Proxy Daemon to sign/verify emails with DKIM signatures
Name: dkimproxy
Version: %{version}
Release: %{rpmrelease}%{?dist}
License: GPLv2+
Group: System Environment/Daemons
URL: http://%{name}.sourceforge.net/
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
Source0: http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
%if %{_has_systemd}
Source1: %{name}@.%{_servicefile_postfix}
Source100: %{name}.%{_has_systemd}.target
Source2: %{name}-tmpfiles.conf
%else
Source1: %{name}.%{_servicefile_postfix}
%endif
Source3: %{name}.sysconfig
Source4: %{name}-execpriv.defaults
Source5: %{name}-mainin.inst.sample
Source6: %{name}-mainout.inst.sample
Source7: %{name}-mainin.local
Source8: %{name}-mainout.local
Source9: %{name}.README
Source10: %{name}.README.RPM
Patch0: dkimproxy-1.4.1-signature_typo.patch
Patch1: dkimproxy-1.4.1-textwrap.patch
Patch2: dkimproxy-1.4.1-ipv4.patch
Patch3: dkimproxy-1.4.1-ipv6.patch
Patch4: dkimproxy-1.4.1-perl_shebang.patch
Patch5: dkimproxy-1.4.1-configure.patch
Patch6: dkimproxy-1.4.1-header.patch
Patch7: dkimproxy-1.4.1-double_signatures.patch
Patch99: http://deb.debian.org/debian/pool/main/d/%{name}/%{name}_%{debianpatchrelease}.diff.gz
# patches => 100 should/will be fixed in SCM
BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: %{__perl}
Requires: exec-tools >= 0.9, openssl, postfix
Requires(pre): %{_sbindir}/groupadd, %{_sbindir}/useradd
%if %{_has_systemd}
BuildRequires: systemd
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif

%description
DKIMproxy is an SMTP Proxy Daemon to sign and or verify emails with
DKIM signatures. It comprises two separate proxies, an "outbound"
proxy for signing outgoing emails and an "inbound" proxy for verifying
signatures of incoming emails. With Postfix, the proxies can operate
as either Before-Queue or After-Queue content filters.

%prep
%setup -q
# apply SCM patches first, other patches my depend on them

# do all other patches
%patch99 -p1
%patch0 -p1 -b .signature_typo
%patch1 -p1 -b .textwrap
%patch2 -p1 -b .ipv4
%patch3 -p1 -b .ipv6
%patch4 -p1 -b .perl_shebang
%patch5 -p1 -b .configure
%patch6 -p1 -b .header
%patch7 -p1 -b .double_signatures

%build
%{configure}
%{__make}

# add version info
%{__perl} -pi -e 's|__DKIM_PROXY_VERSION__|%{version}|g' scripts/%{name}.out

%{__install} -m 0644 -p %{SOURCE10} README.RPM

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__make} install DESTDIR=%{buildroot} INSTALL="install -p" \
  sysconfdir=%{_sysconfdir}/%{name}.d bindir=%{_sbindir} perllibdir=%{perl_vendorlib}

%{__install} -d %{buildroot}%{_bindir}
%{__install} -d %{buildroot}%{_sysconfdir}/sysconfig
%{__install} -d %{buildroot}%{_sysconfdir}/pki/%{name}
%{__install} -d %{buildroot}%{_mandir}/man1
%{__install} -d %{buildroot}%{_pidbasedir}/%{name}

%if %{_has_systemd}
%{__install} -d %{buildroot}%{_prefix}/lib/tmpfiles.d
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -d %{buildroot}%{_unitdir}-generators
%{__install} -m 0644 -p %{SOURCE2} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{__install} -m 0644 -p %{SOURCE1} %{buildroot}%{_unitdir}/%{name}@.service
%{__install} -m 0644 -p %{SOURCE100} %{buildroot}%{_unitdir}/%{name}.target
%{__ln_s} -f execpriv-generator %{buildroot}%{_unitdir}-generators/%{name}-generator
%else
%{__install} -d %{buildroot}%{_initrddir}
%{__install} -m 0755 -p %{SOURCE1} %{buildroot}%{_initrddir}/%{name}
%endif

%{__install} -m 0644 -p %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{__install} -m 0644 -p %{SOURCE4} %{buildroot}%{_sysconfdir}/%{name}.d/execpriv.defaults
%{__install} -m 0644 -p %{SOURCE5} %{buildroot}%{_sysconfdir}/%{name}.d/mainin.inst.sample
%{__install} -m 0644 -p %{SOURCE6} %{buildroot}%{_sysconfdir}/%{name}.d/mainout.inst.sample
%{__install} -m 0644 -p %{SOURCE7} %{buildroot}%{_sysconfdir}/%{name}.d/mainin.local
%{__install} -m 0644 -p %{SOURCE8} %{buildroot}%{_sysconfdir}/%{name}.d/mainout.local
%{__install} -m 0644 -p %{SOURCE9} %{buildroot}%{_sysconfdir}/%{name}.d/README
%{__install} -m 0644 -p debian/man/dkim_responder.1 %{buildroot}%{_mandir}/man1/

# reinstall original files again
%{__install} -m 0755 -p scripts/%{name}.in %{buildroot}%{_sbindir}/
%{__install} -m 0755 -p scripts/%{name}.out %{buildroot}%{_sbindir}/
%{__install} -m 0755 -p scripts/dkim_responder.pl %{buildroot}%{_bindir}/dkim_responder

# rename some files
%{__mv} -vf %{buildroot}%{_mandir}/man8/dkimproxy_in.8 \
  %{buildroot}%{_mandir}/man8/dkimproxy.in.8
%{__mv} -vf %{buildroot}%{_mandir}/man8/dkimproxy_out.8 \
  %{buildroot}%{_mandir}/man8/dkimproxy.out.8

# remove not packaged files
%{__rm} -f %{buildroot}%{_sbindir}/dkim_responder.pl
%{__rm} -f %{buildroot}%{_sysconfdir}/%{name}.d/%{name}_in.conf.example
%{__rm} -f %{buildroot}%{_sysconfdir}/%{name}.d/%{name}_out.conf.example

# fix permissions
find %{buildroot}%{perl_vendorlib} -type f -name "*.pm" -exec %{__chmod} -v 0644 {} \;

# create ghost files
touch %{buildroot}%{_sysconfdir}/pki/%{name}/mainout-private.key
touch %{buildroot}%{_sysconfdir}/pki/%{name}/mainout-public.key
touch %{buildroot}%{_sysconfdir}/pki/%{name}/mainout-dns-records.txt

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%pre
getent group %{_user} > /dev/null || %{_sbindir}/groupadd -r %{_user} 2> /dev/null || :
getent passwd %{_user} > /dev/null || \
  %{_sbindir}/useradd -g %{_user} -s /sbin/nologin -r -M -c "DKIM Proxy User" -d %{_pidbasedir}/%{name} %{_user} 2> /dev/null || :

%post
%if %{_has_systemd}
%systemd_post %{name}.target
%else
/sbin/chkconfig --add %{name}
%endif
# create default keys and DNS resource records file
INSTANCE="mainout" /bin/bash %{_sysconfdir}/%{name}.d/mainout.local

%preun
%if %{_has_systemd}
%systemd_preun %{name}.target
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name} stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{name}
fi
%endif

%postun
%if %{_has_systemd}
%systemd_postun_with_restart %{name}.target
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING INSTALL NEWS README README.RPM TODO
%doc smtpprox.ChangeLog smtpprox.README smtpprox.TODO
%doc scripts/%{name}_in.conf.example scripts/%{name}_out.conf.example
%doc debian/README.Debian
%{_bindir}/dkim_responder
%{_sbindir}/%{name}.in
%{_sbindir}/%{name}.out
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%dir %{_sysconfdir}/%{name}.d
%config(noreplace) %{_sysconfdir}/%{name}.d/mainin.inst.sample
%config(noreplace) %{_sysconfdir}/%{name}.d/mainout.inst.sample
%config(noreplace) %{_sysconfdir}/%{name}.d/mainin.local
%config(noreplace) %{_sysconfdir}/%{name}.d/mainout.local
%config(noreplace) %{_sysconfdir}/%{name}.d/execpriv.defaults
%{_sysconfdir}/%{name}.d/README
%dir %{_sysconfdir}/pki/%{name}
%if %{_has_systemd}
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{_unitdir}/%{name}@.service
%{_unitdir}/%{name}.target
%{_unitdir}-generators/%{name}-generator
%else
%config %{_initrddir}/%{name}
%endif
%{_mandir}/man1/dkim_responder.1*
%{_mandir}/man8/%{name}.in.8*
%{_mandir}/man8/%{name}.out.8*
%dir %{perl_vendorlib}/MSDW
%dir %{perl_vendorlib}/MSDW/SMTP
%{perl_vendorlib}/*.pm
%{perl_vendorlib}/*/*/*.pm
%attr(0775,root,%{_user}) %dir %{_pidbasedir}/%{name}
%attr(0640,root,%{_user}) %ghost %config(missingok,noreplace) %verify(not md5 size mtime) %{_sysconfdir}/pki/%{name}/mainout-private.key
%ghost %config(missingok,noreplace) %verify(not md5 size mtime) %{_sysconfdir}/pki/%{name}/mainout-public.key
%ghost %config(missingok,noreplace) %verify(not md5 size mtime) %{_sysconfdir}/pki/%{name}/mainout-dns-records.txt

%changelog
* Mon Apr 20 2020 Simon Matter <simon.matter@invoca.ch> 1.4.1-4
- add support for EL8

* Sat Mar 23 2019 Simon Matter <simon.matter@invoca.ch> 1.4.1-3
- make mainout.local expand file names in Postfix configuration options
- make mainout.local preserve time stamped copies of DNS include files

* Wed Dec 12 2018 Simon Matter <simon.matter@invoca.ch> 1.4.1-2
- add double_signatures patch
- improve variables detection and samples

* Tue Dec 11 2018 Simon Matter <simon.matter@invoca.ch> 1.4.1-1.3
- add README.Debian to package

* Tue Dec 11 2018 Simon Matter <simon.matter@invoca.ch> 1.4.1-1.2
- revert sample changes back to using IP addresses

* Tue Dec 11 2018 Simon Matter <simon.matter@invoca.ch> 1.4.1-1.1
- make mainout.local preserve a copy of the old DNS include file
- change 127.0.0.1 to localhost in sample files

* Fri Dec 07 2018 Simon Matter <simon.matter@invoca.ch> 1.4.1-1
- initial build
